rm(list=ls(all=T))
library(cladeMode)
phylo <- read.tree("Chiroptera.tre")
yy <- read.csv("Chiroptera.csv", row.names=1)
yy <- as.matrix(yy)
bm <- cladeMode(phylo, yy[,1], mode="BM", contrasts=T)
eb <- cladeMode(phylo, yy[,1], mode="EB", contrasts=T)
ou <- cladeMode(phylo, yy[,1], mode="OU", contrasts=T)
bin <- ceiling(0.25 * Ntip(phylo))
nbr <- cladeMode(phylo, yy[,1], minSize=bin, mode="nestedEBRate", contrasts=T, Ncores=8)
nb <- cladeMode(phylo, yy[,1], minSize=bin, mode="nestedEB", contrasts=T, Ncores=8)
no <- cladeMode(phylo, yy[,1], minSize=bin, mode="nestedOU", contrasts=T, Ncores=8)
nr <- cladeMode(phylo, yy[,1], minSize=bin, mode="rateShift", contrasts=T, Ncores=8)
allResults <- list(bm, eb, ou, nbr, nb, no, nr)
allResults <- sapply(allResults, unlist)
names(allResults) <- c("BM", "EB", "OU", "nestedEBRate", "nestedEB", "nestedOU", "nestedRate")
dput(allResults, "Chiroptera_results.txt")
bin <- ceiling(0.25 * Ntip(phylo))
diffAICc <- mclapply(1:1000, mc.cores=8, function(x) {
y <- cladeModeSim(n=1, phylo, model="BM")[,1]
bm <- cladeMode(phylo, y, mode="BM", contrasts=T)$aicc
mod2 <- cladeMode(phylo, y, mode="EB", contrasts=T)$aicc
mod3 <- cladeMode(phylo, y, mode="OU", contrasts=T)$aicc
mod4 <- cladeMode(phylo, y, minSize=bin, mode="nestedEBRate", contrasts=T, Ncores=1)$aicc
mod5 <- cladeMode(phylo, y, minSize=bin, mode="nestedEB", contrasts=T, Ncores=1)$aicc
mod6 <- cladeMode(phylo, y, minSize=bin, mode="nestedOU", contrasts=T, Ncores=1)$aicc
mod7 <- cladeMode(phylo, y, minSize=bin, mode="rateShift", contrasts=T, Ncores=1)$aicc
c(bm, mod2, mod3, mod4, mod5, mod6, mod7)
})
cutOff <- sapply(diffAICc, function(x) x[1] - x[-1])
aics <- as.matrix(apply(cutOff, 1, function(x) quantile(x, 0.95)))
rownames(aics) <- c("EB", "OU", "nestedEBRate", "nestedEB", "nestedOU", "nestedRate")
write.table(aics, "Chiroptera_AICc_cutoff.txt",row.names=T, col.names=F)
